Skip to contents

Creates an interactive girafe plot, whereby the user can select points with dubious quality and impute new values.

Usage

ggiraph_plot(
  input_variable,
  scale_ref = FALSE,
  point_size = 3,
  vars_to_show = NULL
)

Arguments

input_variable

The name of the variable within the query data frame to plot.

Value

OUTPUT_DESCRIPTION

Details

Custom plotting function for each variable

DETAILS