Skip to contents

Creates an interactive girafe plot, whereby the user can select points with dubious quality and impute new values.

Usage

ggiraph_plot(input_variable)

Arguments

input_variable

The name of the variable within the query data frame to plot.

Value

OUTPUT_DESCRIPTION

Details

Custom plotting function for each variable

DETAILS