ggiraph_plot
ggiraph_plot.RdCreates an interactive girafe plot, whereby the user can select points with dubious quality and impute new values.

ggiraph_plot.RdCreates an interactive girafe plot, whereby the user can select points with dubious quality and impute new values.