Subset a `metamet` object by date
subset_by_date.RdSubsets a `metamet` object to a date range between a start and end date. This is applied to the observation data (`dt`) and the QC (`dt_qc`) and reference data (`dt_ref`) if they are present.
Details
- Limits all time-referenced data to between the start and end dates. - Dates are inclusive. - Warns if date variable not present.
See also
- rename_era5 for variable renaming
- time_average_dt for time-averaging implementation
- metamet for object construction